# cdk

Well-Architected CDK Patterns in Python from https://cdkpatterns.com/patterns/well-architected/

# Available Patterns
- ApiLambdaRds
- ApiLambdaDynamodb
- ApiLambdaDynamodbEventBridgeLambda
- AutoscalingEcsService
- AutoscalingEcsServiceWithPlacement
- AutoscalingEcsCluster
- AlbAutoscalingEcsService
- NlbAutoscalingEcsService
- NlbFargateService
- NlbAutoscalingFargateService
- ApiLambdaEventBridgeLambda
- ApiLambdaSqsLambdaDynamodb
- ApiSnsLambdaEventBridgeLambda
- ApiSnsSqsLambda
- ApiStepFunctions
- LambdaFat
- LambdaLith
- LambdaPowerTuner
- LambdaSinglePurpose
- RestApiDynamodb
- RestApiSns
- S3SqsLambdaEcsEventBridgeLambdaDynamodb
- SagaStepFunction
- SimpleGraphqlService
- SnsLambda
- SnsLambdaSns
- SnsLambdaDynamodb
- SqsLambdaSqs
- WafApiLambdaDynamodb